@@ -1,6 +1,8 @@
 # Impacket - Collection of Python classes for working with network protocols.
 #
-# SECUREAUTH LABS. Copyright (C) 2020 SecureAuth Corporation. All rights reserved.
+# Copyright Fortra, LLC and its affiliated companies 
+#
+# All rights reserved.
 #
 # This software is provided under a slightly modified version
 # of the Apache Software License. See the accompanying LICENSE file
@@ -161,18 +163,22 @@ FILE_ATTRIBUTE_TEMPORARY           = 0x00000100
 FILE_ATTRIBUTE_INTEGRITY_STREAM    = 0x00000800
 FILE_ATTRIBUTE_NO_SCRUB_DATA       = 0x00020000
 
-# Share Access
-FILE_SHARE_READ         = 0x00000001
-FILE_SHARE_WRITE        = 0x00000002
-FILE_SHARE_DELETE       = 0x00000004
+# ShareAccess flags
+# A 32-bit field that specifies how the file SHOULD be shared with other processes.
+# As Specified in section 2.2.13 SMB2 CREATE Request.
+FILE_SHARE_READ                  = 0x00000001 # Other open operations can be performed on the file for read access.
+FILE_SHARE_WRITE                 = 0x00000002 # Other open operations can be performed on the file for write access.
+FILE_SHARE_DELETE                = 0x00000004 # Other open operations can be performed on the file for delete access.
 
 # Create Disposition
-FILE_SUPERSEDE          = 0x00000000
-FILE_OPEN               = 0x00000001
-FILE_CREATE             = 0x00000002
-FILE_OPEN_IF            = 0x00000003
-FILE_OVERWRITE          = 0x00000004
-FILE_OVERWRITE_IF       = 0x00000005
+# Defines the action the server MUST take if the file that is specified in the name field already exists.
+# As Specified in section 2.2.13 SMB2 CREATE Request.
+FILE_SUPERSEDE          = 0x00000000 # If the file already exists, supersede it. Otherwise, create the file. This value SHOULD NOT be used for a printer object.
+FILE_OPEN               = 0x00000001 # If the file already exists, return success; otherwise, fail the operation. MUST NOT be used for a printer object. 
+FILE_CREATE             = 0x00000002 # If the file already exists, fail the operation; otherwise, create the file. 
+FILE_OPEN_IF            = 0x00000003 # Open the file if it already exists; otherwise, create the file. This value SHOULD NOT be used for a printer object.
+FILE_OVERWRITE          = 0x00000004 # Overwrite the file if it already exists; otherwise, fail the operation. MUST NOT be used for a printer object.
+FILE_OVERWRITE_IF       = 0x00000005 # Overwrite the file if it already exists; otherwise, create the file. This value SHOULD NOT be used for a printer object.
 
 # Create Options
 FILE_DIRECTORY_FILE            = 0x00000001
@@ -194,26 +200,28 @@ FILE_OPEN_REPARSE_POINT        = 0x00200000
 FILE_OPEN_NO_RECALL            = 0x00400000
 FILE_OPEN_FOR_FREE_SPACE_QUERY = 0x00800000
 
-# File Access Mask / Desired Access
-FILE_READ_DATA         = 0x00000001
-FILE_WRITE_DATA        = 0x00000002
-FILE_APPEND_DATA       = 0x00000004
-FILE_READ_EA           = 0x00000008
-FILE_WRITE_EA          = 0x00000010
-FILE_EXECUTE           = 0x00000020
-FILE_READ_ATTRIBUTES   = 0x00000080
-FILE_WRITE_ATTRIBUTES  = 0x00000100
-DELETE                 = 0x00010000
-READ_CONTROL           = 0x00020000
-WRITE_DAC              = 0x00040000
-WRITE_OWNER            = 0x00080000
-SYNCHRONIZE            = 0x00100000
-ACCESS_SYSTEM_SECURITY = 0x01000000
-MAXIMUM_ALLOWED        = 0x02000000
-GENERIC_ALL            = 0x10000000
-GENERIC_EXECUTE        = 0x20000000
-GENERIC_WRITE          = 0x40000000
-GENERIC_READ           = 0x80000000
+# File Access Mask (DesiredAccess) flags
+# The level of access that is required, as specified in section 2.2.13.1.
+FILE_READ_DATA          = 0x00000001 # This value indicates the right to read data from the file or named pipe.
+FILE_WRITE_DATA         = 0x00000002 # This value indicates the right to write data into the file or named pipe beyond the end of the file.
+FILE_APPEND_DATA        = 0x00000004 # This value indicates the right to append data into the file or named pipe.
+FILE_READ_EA            = 0x00000008 # This value indicates the right to read the extended attributes of the file or named pipe.
+FILE_WRITE_EA           = 0x00000010 # This value indicates the right to write or change the extended attributes to the file or named pipe.
+FILE_DELETE_CHILD       = 0x00000040 # This value indicates the right to delete entries within a directory.
+FILE_EXECUTE            = 0x00000020 # This value indicates the right to execute the file.
+FILE_READ_ATTRIBUTES    = 0x00000080 # This value indicates the right to read the attributes of the file.
+FILE_WRITE_ATTRIBUTES   = 0x00000100 # This value indicates the right to change the attributes of the file.
+DELETE                  = 0x00010000 # This value indicates the right to delete the file.
+READ_CONTROL            = 0x00020000 # This value indicates the right to read the security descriptor for the file or named pipe.
+WRITE_DAC               = 0x00040000 # This value indicates the right to change the discretionary access control list (DACL) in the security descriptor for the file or named pipe. For the DACL data structure, see ACL in [MS-DTYP].
+WRITE_OWNER             = 0x00080000 # This value indicates the right to change the owner in the security descriptor for the file or named pipe.
+SYNCHRONIZE             = 0x00100000 # SMB2 clients set this flag to any value. SMB2 servers SHOULD ignore this flag.
+ACCESS_SYSTEM_SECURITY  = 0x01000000 # This value indicates the right to read or change the system access control list (SACL) in the security descriptor for the file or named pipe. For the SACL data structure, see ACL in [MS-DTYP].
+MAXIMUM_ALLOWED         = 0x02000000 # This value indicates that the client is requesting an open to the file with the highest level of access the client has on this file. If no access is granted for the client on this file, the server MUST fail the open with STATUS_ACCESS_DENIED.
+GENERIC_ALL             = 0x10000000 # This value indicates a request for all the access flags that are previously listed except MAXIMUM_ALLOWED and ACCESS_SYSTEM_SECURITY.
+GENERIC_EXECUTE         = 0x20000000 # This value indicates a request for the following combination of access flags listed above: FILE_READ_ATTRIBUTES| FILE_EXECUTE| SYNCHRONIZE| READ_CONTROL.
+GENERIC_WRITE           = 0x40000000 # This value indicates a request for the following combination of access flags listed above: FILE_WRITE_DATA| FILE_APPEND_DATA| FILE_WRITE_ATTRIBUTES| FILE_WRITE_EA| SYNCHRONIZE| READ_CONTROL.
+GENERIC_READ            = 0x80000000 # This value indicates a request for the following combination of access flags listed above: FILE_READ_DATA| FILE_READ_ATTRIBUTES| FILE_REA
 
 # Directory Access Mask 
 FILE_LIST_DIRECTORY    = 0x00000001
@@ -618,6 +626,7 @@ class SMB2NegotiateContext(Structure):
         ('ContextType','<H=0'),
         ('DataLength','<H=0'),
         ('Reserved','<L=0'),
+        ('_Data', '_-Data', 'self["DataLength"]'),
         ('Data',':=""'),
     )
 
@@ -626,6 +635,7 @@ class SMB2PreAuthIntegrityCapabilities(Structure):
     structure = (
         ('HashAlgorithmCount','<H=0'),
         ('SaltLength','<H=0'),
+        ('_HashAlgorithms', '_-HashAlgorithms', 'self["HashAlgorithmCount"]*2'),
         ('HashAlgorithms',':=""'),
         ('Salt',':=""'),
     )
@@ -634,7 +644,7 @@ class SMB2PreAuthIntegrityCapabilities(Structure):
 class SMB2EncryptionCapabilities(Structure):
     structure = (
         ('CipherCount','<H=0'),
-        ('Ciphers','<H=0'),
+        ('Ciphers',':=""'),
     )
 
 # SMB2_COMPRESSION_CAPABILITIES
@@ -1492,6 +1502,12 @@ class FILE_ALL_INFORMATION(Structure):
         ('NameInformation',':',FILE_NAME_INFORMATION),
     )
 
+class FILE_ATTRIBUTE_TAG_INFORMATION(Structure):
+    structure = (
+        ('FileAttributes','<L'),
+        ('ReparseTag','<L=0'),
+    )
+
 # SMB2_SET_INFO
 class SMB2SetInfo(Structure):
     SIZE = 32
